==> borg-1.4.1.tar.gz: lib/src/utils/file_io.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

// ignore_for_file: public_member_api_docs

import 'dart:io';

import 'package:path/path.dart' as path;
import 'package:plain_optional/plain_optional.dart';

Optional<String> tryToReadFileSync(String filePath) {
  final file = File(filePath);
  if (file.existsSync() && [FileSystemEntityType.file].contains(file.statSync().type)) {
    return Optional(file.readAsStringSync());
  } else {
    return const Optional.none();
  }
}

void saveStringToFileSync(String filePath, String content) {
  Directory(path.dirname(filePath)).createSync(recursive: true);
  File(filePath).writeAsStringSync(content);
}

String absolutizePath(String location) => path.canonicalize(path.absolute(location));

==> borg-1.4.6.tar.gz: lib/src/utils/file_io.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

// ignore_for_file: public_member_api_docs

import 'dart:io';

import 'package:path/path.dart' as path;
import 'package:plain_optional/plain_optional.dart';

Optional<String> tryToReadFileSync(String filePath) {
  final file = File(filePath);
  if (file.existsSync() &&
      [FileSystemEntityType.file].contains(file.statSync().type)) {
    return Optional(file.readAsStringSync());
  } else {
    return const Optional.none();
  }
}

void saveStringToFileSync(String filePath, String content) {
  Directory(path.dirname(filePath)).createSync(recursive: true);
  File(filePath).writeAsStringSync(content);
}

String absolutizePath(String location) =>
    path.canonicalize(path.absolute(location));
